getTabletWidgetMaxWidth static method

double getTabletWidgetMaxWidth()

Gets the maximum width for widgets on tablet screens.

If the device width is greater than the tablet breakpoint (1024), it uses desktopWidgetMaxWidth, otherwise it uses double.infinity.

Implementation

static double getTabletWidgetMaxWidth() {
  final screenWidth = MediaQuery.of(GlobalContext.context).size.width;
  return screenWidth > tabletBreakpoint
      ? desktopWidgetMaxWidth
      : double.infinity;
}